ConversationFilter class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → String
no setteroverride
selectionArgs → List<String>
no setteroverride

Methods

and(ConversationColumn column) → ConversationFilterStatement
Joins two filter statements by the AND operator.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(ConversationColumn column) → ConversationFilterStatement
Joins to filter statements by the OR operator.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited