ConversationFilterStatement class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
not → ConversationFilterStatement
Applies the NOT operator
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

between(String from, String to) → ConversationFilter
Checks whether the column value lies BETWEEN from and to.
inherited
equals(String equalTo) → ConversationFilter
Checks equality between the column value and equalTo value
inherited
greaterThan(String value) → ConversationFilter
Checks whether the value of the column is greater than value
inherited
greaterThanOrEqualTo(String value) → ConversationFilter
Checks whether the value of the column is greater than or equal to value
inherited
inValues(List<String> values) → ConversationFilter
Checks whether the column value is in the provided list of values
inherited
lessThan(String value) → ConversationFilter
Checks whether the value of the column is less than value
inherited
lessThanOrEqualTo(String value) → ConversationFilter
Checks whether the value of the column is less than or equal to value
inherited
like(String value) → ConversationFilter
Checks whether the column value is LIKE the provided string value
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEqualTo(String value) → ConversationFilter
Checks for inequality between the column value and value
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited