SmsFilter class

Filter to be applied to a SMS query operation.

Works like a SQL WHERE clause.

Public constructor:

SmsFilter.where();

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → String
Do not call this method. This method is visible only for testing.
no setteroverride
selectionArgs → List<String>
Do not call this method. This method is visible only for testing.
no setteroverride

Methods

and(SmsColumn column) → SmsFilterStatement
Joins two filter statements by the AND operator.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(SmsColumn column) → SmsFilterStatement
Joins to filter statements by the OR operator.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

where(SmsColumn column) → SmsFilterStatement