SmsMessage class

Represents a message returned by one of the query functions such as getInboxSms, getSentSms, getDraftSms

Constructors

SmsMessage.fromMap(Map rawMessage, List<SmsColumn> columns)
Do not call this method. This method is visible only for testing.

Properties

address ↔ String?
getter/setter pair
body ↔ String?
getter/setter pair
date ↔ int?
getter/setter pair
dateSent ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
read ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seen ↔ bool?
getter/setter pair
serviceCenterAddress ↔ String?
getter/setter pair
status ↔ SmsStatus?
getter/setter pair
subject ↔ String?
getter/setter pair
subscriptionId ↔ int?
getter/setter pair
threadId ↔ int?
getter/setter pair
type ↔ SmsType?
getter/setter pair

Methods

equals(SmsMessage other) → bool
Do not call this method. This method is visible only for testing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited